-- Custom excess heat capacity term for CpFit
-- Cp(T)/R = CpE(T)/R + a*T + b*T^2 model implementation
-- Chase M.W. et al. // Calphad Vol. 19, NO. 4, pp. 437-447, 1995
return {
	type = 'EPPOLY',
	description = 'Einstein + poly',
	formula = 'C_p/R=3x^2e^x/(e^x-1)^2+aT+bT^2; x=θ/T',
	cpfunc = function(T, lsqparam, fixparam, Tmin, Tmax)
		local theta = lsqparam[1]
		local a, b = lsqparam[2], lsqparam[3]
		local x = theta / T
		local ex = math.exp(x)
		local cp = 0
		if x < 300 then
			cp = R * (3*x^2 * ex / (ex - 1) ^ 2 + a*T + b*T^2);
		else
			cp = R * (3*x^2 / ex + a*T + b*T^2);
		end
		return cp
	end,
	lsqparam = {100, 0, 0},
	lsqparam_names = {'theta', 'a', 'b'},
	lsqparam_lb = {0,   -1e5, -1e5},
	lsqparam_ub = {1e5,  1e5,  1e5},
	fixparam = {},	
	fixparam_names = {},
	Tmin = 0.0,
	Tmax = 3000.0
}
